# Author: Logan Tucker
# Date: 10.25.2021
# Purpose: draw a body


from cs1lib import *


# Constants
TIMESTEP_PARTS = 100


class Body:
    def __init__(self, image_name, mass, x, y,pos_adjustment, vx, vy):
        # image id
        self.img = load_image(image_name)

        # location
        self.x = x
        self.y = y
        self.pos_adjustment = pos_adjustment  # place image center atop the x and y coordinates provided

        # velocity
        self.vx = vx
        self.vy = vy
        self.mass = mass

    # Purpose: Update the x and y coordinates of the body
    # Parameter: (Timestep) representing the rate at which things change in relation to the frame rate
    def update_position(self, timestep):
        subdivided_timestep = timestep / TIMESTEP_PARTS
        for i in range(TIMESTEP_PARTS):  # update the position by smaller increments of time to be more accurate
            self.x += (self.vx * subdivided_timestep)
            self.y += (self.vy * subdivided_timestep)

    # Purpose: Update the x and y velocity of the body
    # Parameter: (ax, ay) the x and y directional accelerations of the body, (Timestep) representing the rate at which
    # things change in relation to the frame rate
    def update_velocity(self, ax, ay, timestep):
        subdivided_timestep = timestep / TIMESTEP_PARTS
        for i in range(TIMESTEP_PARTS):  # update the velocity by smaller increments of time to be more accurate
            self.vx += (ax * subdivided_timestep)
            self.vy += (ay * subdivided_timestep)

    # Purpose: Draw the body instance's image in its most current position
    # Parameter: (cx, cy) the coordinates of the center of simulation, (pixels_per_meter) the scale of the simulation
    def draw(self, cx, cy, pixels_per_meter):
        draw_image(self.img, (cx + (self.x * pixels_per_meter)) - self.pos_adjustment,
                   ((cy*2) - (cy + (self.y * pixels_per_meter))) - self.pos_adjustment)
