# Author: Logan Tucker
# Date: 10.25.2021
# Purpose: draw a series of bodies


from math import sqrt

# set constants
G = 6.67384e-11


class System:
    def __init__(self, body_list):
        self.body_list = body_list

    # Purpose: Compute the current x and y directional acceleration of a body in the system
    # Parameters: (current_index) the body in the system of which we are currently calculating the acceleration
    def compute_acceleration(self, current_index):
        ax = 0  # x axis acceleration
        ay = 0  # y axis acceleration
        for body in self.body_list:
            if body != current_index:  # a body cannot affect its own acceleration
                # distances between bodies
                x_distance = (body.x - current_index.x)
                y_distance = (body.y - current_index.y)

                total_distance = sqrt((x_distance ** 2) + (y_distance ** 2))

                # acceleration
                acceleration = (G * body.mass) / (total_distance ** 2)

                x_acceleration = (acceleration * x_distance) / total_distance
                y_acceleration = (acceleration * y_distance) / total_distance

                # sum of all other planets effect on the current planets acceleration
                ax += x_acceleration
                ay += y_acceleration

        current_acceleration = (ax, ay)

        return current_acceleration

    # Purpose: Update the position and velocity of each body instance in the list
    # Parameter: (Timestep) representing the rate at which things change in relation to the frame rate
    def update(self, timestep):
        for body in self.body_list:
            body.update_position(timestep)

            (ax, ay) = self.compute_acceleration(body)  # save return value in two separate variables

            body.update_velocity(ax, ay, timestep)

    # Purpose: draw each body instance in the list at its current location
    # Parameter: (cx, cy) the coordinates of the center of simulation, (pixels_per_meter) the scale of the simulation
    def draw(self, cx, cy, pixels_per_meter):
        for body in self.body_list:  # cycle through each object in the list and draw it
            body.draw(cx, cy, pixels_per_meter)